<?php

class VDEVShopifyProduct extends VDEVShopify
{
    public function getProducts($limit = 250, $pagination = false, $pageInfo = null)
    {
        $callURI = '/admin/api/2021-10/products.json';
        $call = $this->call($callURI, [], 'GET');
        
        return $this->getCallResponse($call, 'products', $pagination);
    }

    public function getProductById($productId)
    {
        $callURI = '/admin/api/2021-10/products/' . (int)$productId . '.json';
        $call = $this->call($callURI, [], 'GET');
        
        return $this->getCallResponse($call, 'product');
    }
    
    public function updateProductVariantById($variantId, $newProductVariant) {
        $callURI = '/admin/api/2022-04/variants/' . (int)$variantId . '.json';
        $callData = [
            'variant' => $newProductVariant
        ];
        $call = $this->call($callURI, $callData, 'PUT');
        
        return $this->getCallResponse($call, 'variant');
    }
    
    public function getProductVariantById($variantId) {
        $locations = $this->getLocations();
        
        $callURI = '/admin/api/2022-04/variants/' . (int)$variantId . '.json';
        $callData = [];
        $call = $this->call($callURI, $callData, 'GET');
        
        return $this->getCallResponse($call, 'variant');
    }
    
    public function getInventoryLevelsById($inventoryItemId) {
        $callURI = '/admin/api/2022-04/inventory_levels.json';
        $callData = [
            'inventory_item_ids' => $inventoryItemId
        ];
        $call = $this->call($callURI, $callData, 'GET');
        
        return $this->getCallResponse($call, 'inventory_levels');
    }
    
    public function getProductLocations($variantId) {
        $locations = $this->getLocations();
        $productVariant = $this->getProductVariantById($variantId);
        $productInventoryLevels = $this->getInventoryLevelsById($productVariant['inventory_item_id']);
        
        $productLocations = [];
        
        foreach ($locations as $location) {
            $productLocation = [
                'name' => $location['name'],
                'address' => (!empty($location['address2']) ? $location['address2'] . ', ' : '') . $location['address1'] . ', ' . $location['city'] . ', ' . $location['province_code'] . ' ' . $location['zip'],
                'phone' => $location['phone']
            ];
            
            $productLocation['iframe_url'] = 'https://maps.google.com/maps?width=100%&height=600&hl=en&q=' . urlencode('Love Isabelle Jewellery, ' . $productLocation['address']) . '&t=&z=16&ie=UTF8&iwloc=B&output=embed';
            
            foreach ($productInventoryLevels as $productInventoryLevel) {

                if ($productInventoryLevel['location_id'] == $location['id']) {
                    $productLocation['available'] = $productInventoryLevel['available'];
                }
            }
            
            if ($location['name'] == 'Manly') {
                $productLocation['phone'] = '0431 395 965';
            
            } else if ($location['name'] == 'Byron Bay') {
                $productLocation['phone'] = '0401 668 406';
            }
            
            if ($location['name'] == 'Manly' || $location['name'] == 'Byron Bay') {
                $productLocations[] = $productLocation;
            }
        }
        
        usort($productLocations, function ($item1, $item2) {
            return $item2['name'] <=> $item1['name'];
        });
        
        return $productLocations;
    }
    
    public function getLocations() {
        $callURI = '/admin/api/2022-04/locations.json';
        $callData = [];
        $call = $this->call($callURI, $callData, 'GET');
        
        return $this->getCallResponse($call, 'locations');
    }
    
    
    /*** NEW ***/
    public function getById($id)
    {
        $callURI = '/admin/api/2022-10/products/' . (int)$id . '.json';
        $call = $this->call($callURI, [], 'GET');
        
        return $this->getCallResponse($call, 'product');
    }
    
    public function getAll($callData = [], $pagintation = false)
    {
        $callURI = '/admin/api/2022-10/products.json';
        $call = $this->call($callURI, $callData, 'GET');
        
        return $this->getCallResponse($call, 'products', $pagintation);
    }
    
    /* Metafields */
    public function getMetafieldsById($id, $namespace = null, $key = null) 
    {
        $callURI = '/admin/api/2022-10/metafields.json';
        $callQueries = [
            'metafield' => [
                'owner_id' => (int)$id,
                'owner_resource' => 'product'
            ]
        ];
        
        $call = $this->call($callURI, $callQueries, 'GET');
        
        if ($namespace && $key) {
            $metafields = $this->getCallResponse($call, 'metafields');
            
            if (!empty($metafields)) {
                
                foreach ($metafields as $metafield) {
                    
                    if (!empty($metafield['namespace']) && !empty($metafield['namespace'])) {
                        
                        if ($metafield['namespace'] == $namespace && $metafield['key'] == $key) {
                            return $metafield['value'];
                        }
                    }
                }
            } 
            
            return null;
        
        } else {
            return $this->getCallResponse($call, 'metafields');  
        }
    }
    
    public function setMetafieldById($id, $metafield) 
    {
        $callURI = '/admin/api/2022-10/products/' . (int)$id . '/metafields.json';
        $callQueries = [
            'metafield' => $metafield
        ];
        $call = $this->call($callURI, $callQueries, 'POST');
        
        return $this->getCallResponse($call, 'metafield');  
    }
    
    public function setById($id, $product)
    {
        $callURI = '/admin/api/2022-10/products/' . (int)$id . '.json';
        $callQueries = [
            'product' => $product
        ];
        $call = $this->call($callURI, $callQueries, 'POST');
        
        return $this->getCallResponse($call, 'product');
    }
    /* /Metafields */
    /*** /NEW ***/
}
